==> haskell-attoparsec-0.14.4-76-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-attoparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 z-attoparsec-z-attoparsec-internal
version:              0.14.4
package-name:         attoparsec
lib-name:             attoparsec-internal
id:
    attoparsec-0.14.4-I1ILrzTUkNo4NQaM5zrRk4-attoparsec-internal

key:
    attoparsec-0.14.4-I1ILrzTUkNo4NQaM5zrRk4-attoparsec-internal

license:              BSD-3-Clause
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>, Ben Gamari <ben@smart-cactus.org>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/bgamari/attoparsec
synopsis:             Fast combinator parsing for bytestrings and text
description:
    A fast parser combinator library, aimed particularly at dealing
    efficiently with network protocols and complicated text/binary
    file formats.

category:             Text, Parsing
abi:                  96aac4cc020f628cdf25a47c3add3ab5
exposed-modules:
    Data.Attoparsec.ByteString.Buffer
    Data.Attoparsec.ByteString.FastSet Data.Attoparsec.Internal.Compat
    Data.Attoparsec.Internal.Fhthagn Data.Attoparsec.Text.Buffer
    Data.Attoparsec.Text.FastSet

import-dirs:          /usr/lib/ghc-9.2.8/site-local/attoparsec-0.14.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/attoparsec-0.14.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-attoparsec
hs-libraries:
    HSattoparsec-0.14.4-I1ILrzTUkNo4NQaM5zrRk4-attoparsec-internal

depends:
    array-0.5.4.0 base-4.16.4.0 bytestring-0.11.4.0 text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-attoparsec/html/attoparsec.haddock
haddock-html:         /usr/share/doc/haskell-attoparsec/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 attoparsec
version:              0.14.4
visibility:           public
id:                   attoparsec-0.14.4-7zFXPvsAeTc17D9FbG47Bq
key:                  attoparsec-0.14.4-7zFXPvsAeTc17D9FbG47Bq
license:              BSD-3-Clause
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>, Ben Gamari <ben@smart-cactus.org>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/bgamari/attoparsec
synopsis:             Fast combinator parsing for bytestrings and text
description:
    A fast parser combinator library, aimed particularly at dealing
    efficiently with network protocols and complicated text/binary
    file formats.

category:             Text, Parsing
abi:                  0e3cf00db66c9c4469f541f790962225
exposed:              True
exposed-modules:
    Data.Attoparsec Data.Attoparsec.ByteString
    Data.Attoparsec.ByteString.Char8 Data.Attoparsec.ByteString.Lazy
    Data.Attoparsec.Char8 Data.Attoparsec.Combinator
    Data.Attoparsec.Internal Data.Attoparsec.Internal.Types
    Data.Attoparsec.Lazy Data.Attoparsec.Number Data.Attoparsec.Text
    Data.Attoparsec.Text.Lazy Data.Attoparsec.Types
    Data.Attoparsec.Zepto

hidden-modules:
    Data.Attoparsec.ByteString.Internal Data.Attoparsec.Text.Internal

import-dirs:          /usr/lib/ghc-9.2.8/site-local/attoparsec-0.14.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/attoparsec-0.14.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-attoparsec
hs-libraries:         HSattoparsec-0.14.4-7zFXPvsAeTc17D9FbG47Bq
depends:
    array-0.5.4.0
    attoparsec-0.14.4-I1ILrzTUkNo4NQaM5zrRk4-attoparsec-internal
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    deepseq-1.4.6.1 ghc-prim-0.8.0
    scientific-0.3.7.0-8x4tZ4xzXsRTNLFKkeuvD text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-attoparsec/html/attoparsec.haddock
haddock-html:         /usr/share/doc/haskell-attoparsec/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-attoparsec-0.14.4-105.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-attoparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-attoparsec-z-attoparsec-internal
version:              0.14.4
package-name:         attoparsec
lib-name:             attoparsec-internal
id:
    attoparsec-0.14.4-BUjLMh8PRpd75iTZjiTkYr-attoparsec-internal

key:
    attoparsec-0.14.4-BUjLMh8PRpd75iTZjiTkYr-attoparsec-internal

license:              BSD-3-Clause
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>, Ben Gamari <ben@smart-cactus.org>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/bgamari/attoparsec
synopsis:             Fast combinator parsing for bytestrings and text
description:
    A fast parser combinator library, aimed particularly at dealing
    efficiently with network protocols and complicated text/binary
    file formats.

category:             Text, Parsing
abi:                  82a4234ed4da19c397c60b522ab3683c
exposed-modules:
    Data.Attoparsec.ByteString.Buffer
    Data.Attoparsec.ByteString.FastSet Data.Attoparsec.Internal.Compat
    Data.Attoparsec.Internal.Fhthagn Data.Attoparsec.Text.Buffer
    Data.Attoparsec.Text.FastSet

import-dirs:          /usr/lib/ghc-9.4.8/site-local/attoparsec-0.14.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/attoparsec-0.14.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/attoparsec-0.14.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-attoparsec
hs-libraries:
    HSattoparsec-0.14.4-BUjLMh8PRpd75iTZjiTkYr-attoparsec-internal

depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-attoparsec/html/attoparsec.haddock
haddock-html:         /usr/share/doc/haskell-attoparsec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 attoparsec
version:              0.14.4
visibility:           public
id:                   attoparsec-0.14.4-K9rgVNreKMkFhZdMbsqsTo
key:                  attoparsec-0.14.4-K9rgVNreKMkFhZdMbsqsTo
license:              BSD-3-Clause
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>, Ben Gamari <ben@smart-cactus.org>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/bgamari/attoparsec
synopsis:             Fast combinator parsing for bytestrings and text
description:
    A fast parser combinator library, aimed particularly at dealing
    efficiently with network protocols and complicated text/binary
    file formats.

category:             Text, Parsing
abi:                  09bb47c935daebe11c1cf04893a4b6c0
exposed:              True
exposed-modules:
    Data.Attoparsec Data.Attoparsec.ByteString
    Data.Attoparsec.ByteString.Char8 Data.Attoparsec.ByteString.Lazy
    Data.Attoparsec.Char8 Data.Attoparsec.Combinator
    Data.Attoparsec.Internal Data.Attoparsec.Internal.Types
    Data.Attoparsec.Lazy Data.Attoparsec.Number Data.Attoparsec.Text
    Data.Attoparsec.Text.Lazy Data.Attoparsec.Types
    Data.Attoparsec.Zepto

hidden-modules:
    Data.Attoparsec.ByteString.Internal Data.Attoparsec.Text.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/attoparsec-0.14.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/attoparsec-0.14.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/attoparsec-0.14.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-attoparsec
hs-libraries:         HSattoparsec-0.14.4-K9rgVNreKMkFhZdMbsqsTo
depends:
    array-0.5.4.0
    attoparsec-0.14.4-BUjLMh8PRpd75iTZjiTkYr-attoparsec-internal
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    ghc-prim-0.9.1 scientific-0.3.7.0-FVWP8DVCKbGBwiSARe0xui text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-attoparsec/html/attoparsec.haddock
haddock-html:         /usr/share/doc/haskell-attoparsec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
